pub const unsafe fn encode_1() -> EncodedX86_64InstructionExpand description
Generate debug trap. More or less equivalent to int 1.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode_1() -> EncodedX86_64InstructionGenerate debug trap. More or less equivalent to int 1.
This function is safe to call. It is marked as unsafe for consistency with other encoders.