pub const unsafe fn encode_3() -> EncodedX86_64InstructionExpand description
Generate breakpoint trap. More or less equivalent to int 3.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode_3() -> EncodedX86_64InstructionGenerate breakpoint trap. More or less equivalent to int 3.
This function is safe to call. It is marked as unsafe for consistency with other encoders.