encode_imm8

Function encode_imm8 

pub const unsafe fn encode_imm8(imm8: Immediate8) -> EncodedX86_64Instruction
Generate software interrupt with vector specified by immediate byte.

Safety

It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.