pub const unsafe fn encode_imm8(imm8: Immediate8) -> EncodedX86_64InstructionExpand description
Generate software interrupt with vector specified by immediate byte.
Safety
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.